@@ -27,7 +27,12 @@ sub call {
     };
 
     my $caught;
-    my $res = try { $self->app->($env) } catch { $caught = $_ };
+    my $res = try {
+        $self->app->($env);
+    } catch {
+        $caught = $_;
+        [ 500, [ "Content-Type", "text/plain; charset=utf-8" ], [ no_trace_error(utf8_safe($caught)) ] ];
+    };
 
     if ($trace && ($caught || ($self->force && ref $res eq 'ARRAY' && $res->[0] == 500)) ) {
         my $text = $trace->as_string;
@@ -50,6 +55,19 @@ sub call {
     return $res;
 }
 
+sub no_trace_error {
+    my $msg = shift;
+    chomp($msg);
+
+    return <<EOF;
+The application raised the following error:
+
+  $msg
+
+and the StackTrace middleware couldn't catch its stack trace, possibly because your application overrides \$SIG{__DIE__} by itself, preventing the middleware from working correctly. Remove the offending code or module that does it: known examples are CGI::Carp and Carp::Always.
+EOF
+}
+
 sub munge_error {
     my($err, $caller) = @_;
     return $err if ref $err;
